.. opendvp documentation master file, created by
   sphinx-quickstart on Sun May 18 19:36:51 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to openDVP's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   opendvp